@@ -8,7 +8,9 @@
 #' @author Simon Garnier, \email{garnier@@njit.edu}
 #'
 #' @examples
-#' defaultOpenCVPath()
+#' \dontrun{
+#'  defaultOpenCVPath()
+#' }
 #'
 #' @export
 defaultOpenCVPath <- function() {
@@ -181,21 +183,21 @@ installOpenCV <- function(path = defaultOpenCVPath(), batch = FALSE) {
       }
     }
 
-    Sys.setenv(CXX_STD = "CXX11")
+    # Sys.setenv(CXX_STD = "CXX11")
 
     if (.Platform$OS.type == "windows") {
       dir.create(path, showWarnings = FALSE)
       tmpDir <- gsub("\\\\", "/", base::tempdir())
       dir.create(tmpDir, showWarnings = FALSE)
 
-      utils::download.file("https://github.com/opencv/opencv/archive/4.7.0.tar.gz",
-                           paste0(tmpDir, "/opencv-4.7.0.tar.gz"))
-      utils::untar(paste0(tmpDir, "/opencv-4.7.0.tar.gz"),
+      utils::download.file("https://github.com/opencv/opencv/archive/4.8.0.tar.gz",
+                           paste0(tmpDir, "/opencv-4.8.0.tar.gz"))
+      utils::untar(paste0(tmpDir, "/opencv-4.8.0.tar.gz"),
                    exdir = tmpDir)
 
-      utils::download.file("https://github.com/opencv/opencv_contrib/archive/4.7.0.tar.gz",
-                           paste0(tmpDir, "/opencv_contrib-4.7.0.tar.gz"))
-      utils::untar(paste0(tmpDir, "/opencv_contrib-4.7.0.tar.gz"),
+      utils::download.file("https://github.com/opencv/opencv_contrib/archive/4.8.0.tar.gz",
+                           paste0(tmpDir, "/opencv_contrib-4.8.0.tar.gz"))
+      utils::untar(paste0(tmpDir, "/opencv_contrib-4.8.0.tar.gz"),
                    exdir = tmpDir)
 
       arch <- c("64", "32")
@@ -214,8 +216,8 @@ installOpenCV <- function(path = defaultOpenCVPath(), batch = FALSE) {
 
         for (i in 1:2) {
           if (archAvail[i] == TRUE) {
-            sourceDir <- paste0(tmpDir, "/opencv-4.7.0/")
-            contribDir <- paste0(tmpDir, "/opencv_contrib-4.7.0/modules")
+            sourceDir <- paste0(tmpDir, "/opencv-4.8.0/")
+            contribDir <- paste0(tmpDir, "/opencv_contrib-4.8.0/modules")
             buildDir <- paste0(sourceDir, "build", arch[i])
             dir.create(buildDir, showWarnings = FALSE)
             openCVArch <- if (arch[i] == 64) "x64" else "x86"
@@ -227,7 +229,7 @@ installOpenCV <- function(path = defaultOpenCVPath(), batch = FALSE) {
                   gpp_path <- paste0(rtools4Path, "/x86_64-w64-mingw32.static.posix", "/bin/g++.exe")
                   windres_path <- paste0(rtools4Path, "/x86_64-w64-mingw32.static.posix", "/bin/windres.exe")
                   make_path <- paste0(rtools4Path, "/usr/bin/make.exe")
-                  system(paste0('cmake -G "Unix Makefiles" -DCMAKE_C_COMPILER=', gcc_path, ' -DCMAKE_CXX_COMPILER=', gpp_path, ' -DCMAKE_RC_COMPILER=', windres_path, ' -DCMAKE_MAKE_PROGRAM=', make_path, ' -DENABLE_PRECOMPILED_HEADERS=OFF -DOpenCV_ARCH=', openCVArch, ' -DOpenCV_RUNTIME=mingw -DENABLE_CXX11=ON -DBUILD_ZLIB=ON -DOPENCV_EXTRA_MODULES_PATH=', contribDir, ' -DBUILD_LIST=calib3d,core,dnn,features2d,flann,gapi,highgui,imgcodecs,imgproc,ml,objdetect,photo,stitching,video,videoio,ximgproc -DBUILD_opencv_world=OFF -DBUILD_opencv_contrib_world=OFF -DWITH_OPENMP=ON -DWITH_TBB=ON -DWITH_FFMPEG=ON -DWITH_OPENCL=ON -DWITH_EIGEN=ON -DWITH_OPENCLAMDFFT=ON -DWITH_OPENCLAMDBLAS=ON -DBUILD_PERF_TESTS=OFF -DBUILD_TESTS=OFF -DWITH_DSHOW=ON -DBUILD_PROTOBUF=ON -DOPENCV_ENABLE_ALLOCATOR_STATS=OFF -DBUILD_SHARED_LIBS=ON -DCMAKE_BUILD_TYPE=RELEASE -DCMAKE_INSTALL_PREFIX=', path, ' -B', buildDir, ' -H', sourceDir))
+                  system(paste0('cmake -G "Unix Makefiles" -DCMAKE_C_COMPILER=', gcc_path, ' -DCMAKE_CXX_COMPILER=', gpp_path, ' -DCMAKE_RC_COMPILER=', windres_path, ' -DCMAKE_MAKE_PROGRAM=', make_path, ' -DENABLE_PRECOMPILED_HEADERS=OFF -DOpenCV_ARCH=', openCVArch, ' -DOpenCV_RUNTIME=mingw -DBUILD_ZLIB=ON -DOPENCV_EXTRA_MODULES_PATH=', contribDir, ' -DBUILD_LIST=calib3d,core,dnn,features2d,flann,gapi,highgui,imgcodecs,imgproc,ml,objdetect,photo,stitching,video,videoio,ximgproc -DBUILD_opencv_world=OFF -DBUILD_opencv_contrib_world=OFF -DWITH_OPENMP=ON -DWITH_TBB=ON -DWITH_FFMPEG=ON -DWITH_OPENCL=ON -DWITH_EIGEN=ON -DWITH_OPENCLAMDFFT=ON -DWITH_OPENCLAMDBLAS=ON -DBUILD_PERF_TESTS=OFF -DBUILD_TESTS=OFF -DWITH_DSHOW=ON -DBUILD_PROTOBUF=ON -DOPENCV_ENABLE_ALLOCATOR_STATS=OFF -DBUILD_SHARED_LIBS=ON -DCMAKE_BUILD_TYPE=RELEASE -DCMAKE_INSTALL_PREFIX=', path, ' -B', buildDir, ' -H', sourceDir))
                   system(paste0(make_path, " -j", parallel::detectCores(), " -C ", buildDir))
                   system(paste0(make_path, " -C", buildDir, " install"))
                 } else {
@@ -238,7 +240,7 @@ installOpenCV <- function(path = defaultOpenCVPath(), batch = FALSE) {
                 gpp_path <- paste0(rtools4Path, "/mingw", arch[i], "/bin/g++.exe")
                 windres_path <- paste0(rtools4Path, "/mingw", arch[i], "/bin/windres.exe")
                 make_path <- paste0(rtools4Path, "/usr/bin/make.exe")
-                system(paste0('cmake -G "Unix Makefiles" -DCMAKE_C_COMPILER=', gcc_path, ' -DCMAKE_CXX_COMPILER=', gpp_path, ' -DCMAKE_RC_COMPILER=', windres_path, ' -DCMAKE_MAKE_PROGRAM=', make_path, ' -DENABLE_PRECOMPILED_HEADERS=OFF -DOpenCV_ARCH=', openCVArch, ' -DOpenCV_RUNTIME=mingw -DENABLE_CXX11=ON -DBUILD_ZLIB=ON -DOPENCV_EXTRA_MODULES_PATH=', contribDir, ' -DBUILD_LIST=calib3d,core,dnn,features2d,flann,gapi,highgui,imgcodecs,imgproc,ml,objdetect,photo,stitching,video,videoio,ximgproc -DBUILD_opencv_world=OFF -DBUILD_opencv_contrib_world=OFF -DWITH_OPENMP=ON -DWITH_TBB=ON -DWITH_FFMPEG=ON -DWITH_OPENCL=ON -DWITH_EIGEN=ON -DWITH_OPENCLAMDFFT=ON -DWITH_OPENCLAMDBLAS=ON -DBUILD_PERF_TESTS=OFF -DBUILD_TESTS=OFF -DWITH_DSHOW=ON -DBUILD_PROTOBUF=OFF -DOPENCV_ENABLE_ALLOCATOR_STATS=OFF -DBUILD_SHARED_LIBS=ON -DCMAKE_BUILD_TYPE=RELEASE -DCMAKE_INSTALL_PREFIX=', path, ' -B', buildDir, ' -H', sourceDir))
+                system(paste0('cmake -G "Unix Makefiles" -DCMAKE_C_COMPILER=', gcc_path, ' -DCMAKE_CXX_COMPILER=', gpp_path, ' -DCMAKE_RC_COMPILER=', windres_path, ' -DCMAKE_MAKE_PROGRAM=', make_path, ' -DENABLE_PRECOMPILED_HEADERS=OFF -DOpenCV_ARCH=', openCVArch, ' -DOpenCV_RUNTIME=mingw -DBUILD_ZLIB=ON -DOPENCV_EXTRA_MODULES_PATH=', contribDir, ' -DBUILD_LIST=calib3d,core,dnn,features2d,flann,gapi,highgui,imgcodecs,imgproc,ml,objdetect,photo,stitching,video,videoio,ximgproc -DBUILD_opencv_world=OFF -DBUILD_opencv_contrib_world=OFF -DWITH_OPENMP=ON -DWITH_TBB=ON -DWITH_FFMPEG=ON -DWITH_OPENCL=ON -DWITH_EIGEN=ON -DWITH_OPENCLAMDFFT=ON -DWITH_OPENCLAMDBLAS=ON -DBUILD_PERF_TESTS=OFF -DBUILD_TESTS=OFF -DWITH_DSHOW=ON -DBUILD_PROTOBUF=OFF -DOPENCV_ENABLE_ALLOCATOR_STATS=OFF -DBUILD_SHARED_LIBS=ON -DCMAKE_BUILD_TYPE=RELEASE -DCMAKE_INSTALL_PREFIX=', path, ' -B', buildDir, ' -H', sourceDir))
                 system(paste0(make_path, " -j", parallel::detectCores(), " -C ", buildDir))
                 system(paste0(make_path, " -C", buildDir, " install"))
               }
@@ -247,7 +249,7 @@ installOpenCV <- function(path = defaultOpenCVPath(), batch = FALSE) {
               gpp_path <- paste0(rtoolsPath, "/mingw_", arch[i], "/bin/g++.exe")
               windres_path <- paste0(rtoolsPath, "/mingw_", arch[i], "/bin/windres.exe")
               make_path <- paste0(rtoolsPath, "/mingw_", arch[i], "/bin/mingw32-make.exe")
-              system(paste0('cmake -G "Unix Makefiles" -DCMAKE_C_COMPILER=', gcc_path, ' -DCMAKE_CXX_COMPILER=', gpp_path, ' -DCMAKE_RC_COMPILER=', windres_path, ' -DCMAKE_MAKE_PROGRAM=', make_path, ' -DENABLE_PRECOMPILED_HEADERS=OFF  -DOpenCV_ARCH=', openCVArch, ' -DOpenCV_RUNTIME=mingw -DENABLE_CXX11=ON -DBUILD_ZLIB=ON -DOPENCV_EXTRA_MODULES_PATH=', contribDir, ' -DBUILD_LIST=calib3d,core,dnn,features2d,flann,highgui,imgcodecs,imgproc,ml,objdetect,photo,stitching,video,videoio,ximgproc -DBUILD_opencv_world=OFF -DBUILD_opencv_contrib_world=OFF -DWITH_OPENMP=ON -DWITH_TBB=ON -DWITH_FFMPEG=ON -DWITH_OPENCL=ON -DWITH_EIGEN=ON -DWITH_OPENCLAMDFFT=ON -DWITH_OPENCLAMDBLAS=ON -DBUILD_PERF_TESTS=OFF -DBUILD_TESTS=OFF -DWITH_DSHOW=ON -DBUILD_PROTOBUF=OFF -DOPENCV_ENABLE_ALLOCATOR_STATS=OFF -DBUILD_SHARED_LIBS=ON -DCMAKE_BUILD_TYPE=RELEASE -DCMAKE_INSTALL_PREFIX=', path, ' -B', buildDir, ' -H', sourceDir))
+              system(paste0('cmake -G "Unix Makefiles" -DCMAKE_C_COMPILER=', gcc_path, ' -DCMAKE_CXX_COMPILER=', gpp_path, ' -DCMAKE_RC_COMPILER=', windres_path, ' -DCMAKE_MAKE_PROGRAM=', make_path, ' -DENABLE_PRECOMPILED_HEADERS=OFF  -DOpenCV_ARCH=', openCVArch, ' -DOpenCV_RUNTIME=mingw -DBUILD_ZLIB=ON -DOPENCV_EXTRA_MODULES_PATH=', contribDir, ' -DBUILD_LIST=calib3d,core,dnn,features2d,flann,highgui,imgcodecs,imgproc,ml,objdetect,photo,stitching,video,videoio,ximgproc -DBUILD_opencv_world=OFF -DBUILD_opencv_contrib_world=OFF -DWITH_OPENMP=ON -DWITH_TBB=ON -DWITH_FFMPEG=ON -DWITH_OPENCL=ON -DWITH_EIGEN=ON -DWITH_OPENCLAMDFFT=ON -DWITH_OPENCLAMDBLAS=ON -DBUILD_PERF_TESTS=OFF -DBUILD_TESTS=OFF -DWITH_DSHOW=ON -DBUILD_PROTOBUF=OFF -DOPENCV_ENABLE_ALLOCATOR_STATS=OFF -DBUILD_SHARED_LIBS=ON -DCMAKE_BUILD_TYPE=RELEASE -DCMAKE_INSTALL_PREFIX=', path, ' -B', buildDir, ' -H', sourceDir))
               system(paste0(make_path, " -j", parallel::detectCores(), " -C ", buildDir))
               system(paste0(make_path, " -C", buildDir, " install"))
             }
@@ -259,22 +261,22 @@ installOpenCV <- function(path = defaultOpenCVPath(), batch = FALSE) {
       tmpDir <- base::tempdir()
       dir.create(tmpDir, showWarnings = FALSE)
 
-      utils::download.file("https://github.com/opencv/opencv/archive/4.7.0.zip",
-                           paste0(tmpDir, "/opencv-4.7.0.zip"))
-      utils::unzip(paste0(tmpDir, "/opencv-4.7.0.zip"),
+      utils::download.file("https://github.com/opencv/opencv/archive/4.8.0.zip",
+                           paste0(tmpDir, "/opencv-4.8.0.zip"))
+      utils::unzip(paste0(tmpDir, "/opencv-4.8.0.zip"),
                    exdir = tmpDir)
 
-      utils::download.file("https://github.com/opencv/opencv_contrib/archive/4.7.0.zip",
-                           paste0(tmpDir, "/opencv_contrib-4.7.0.zip"))
-      utils::unzip(paste0(tmpDir, "/opencv_contrib-4.7.0.zip"),
+      utils::download.file("https://github.com/opencv/opencv_contrib/archive/4.8.0.zip",
+                           paste0(tmpDir, "/opencv_contrib-4.8.0.zip"))
+      utils::unzip(paste0(tmpDir, "/opencv_contrib-4.8.0.zip"),
                    exdir = tmpDir)
 
-      file.copy(paste0(pkgPath, "/OpenCVModule.4.7.0.cmake"),
-                paste0(tmpDir, "/opencv-4.7.0/cmake/OpenCVModule.cmake"),
+      file.copy(paste0(pkgPath, "/OpenCVModule.4.8.0.cmake"),
+                paste0(tmpDir, "/opencv-4.8.0/cmake/OpenCVModule.cmake"),
                 overwrite = TRUE)
 
-      sourceDir <- paste0(tmpDir, "/opencv-4.7.0/")
-      contribDir <- paste0(tmpDir, "/opencv_contrib-4.7.0/modules")
+      sourceDir <- paste0(tmpDir, "/opencv-4.8.0/")
+      contribDir <- paste0(tmpDir, "/opencv_contrib-4.8.0/modules")
       buildDir <- paste0(sourceDir, "build")
       dir.create(buildDir, showWarnings = FALSE)
 
@@ -385,10 +387,12 @@ opencvVersion <- function() {
 #' @author Simon Garnier, \email{garnier@@njit.edu}
 #'
 #' @examples
-#' if (isOpenCVInstalled()) {
-#'   opencvConfig()
-#'   opencvConfig(output = "cflags")
-#'   opencvConfig(arch = R.version$arch)
+#' \dontrun{
+#'  if (isOpenCVInstalled()) {
+#'    opencvConfig()
+#'    opencvConfig(output = "cflags")
+#'    opencvConfig(arch = R.version$arch)
+#'  }
 #' }
 #'
 #' @export
